pub struct Removed<T: Send + Sync + 'static> { /* private fields */ }Expand description
A value removed from an Atom or AtomOption.
The value can be read via Deref. When this wrapper is dropped,
T’s destructor is deferred through the reclamation system —
it will only run once all concurrent readers have moved on.
This prevents use-after-free when concurrent readers hold an
AtomGuard that references the same value’s internal heap
allocations (e.g. a String’s buffer or Vec’s backing array).
To take ownership without deferral (e.g. when you know no readers
exist), use into_inner_unchecked.
Implementations